from setuptools import setup, find_packages  # type: ignore

setup(
    name="trend_etl",
    version="1.0.1",
    author="Charles Conroy",
    author_email="cconroy@trend.community",
    url="https://github.com/trend-community/data-engineering",
    description="Library for helpers used for ETL jobs.",
    python_requires=">=3.8",
    packages=find_packages(),
    entry_points={
        "read_kafka_subreddits": "read_kafka_subreddits=trend_etl.tasks.read_kafka_subreddits:main",
        "read_kafka_submissions": "read_kafka_submissions=trend_etl.tasks.read_kafka_submissions:main",
        "read_kafka_replies": "read_kafka_replies=trend_etl.tasks.read_kafka_replies:main",
        "read_kafka_guilds": "read_kafka_guilds=trend_etl.tasks.read_kafka_guilds:main",
        "read_kafka_channels": "read_kafka_channels=trend_etl.tasks.read_kafka_channels:main",
        "read_kafka_messages": "read_kafka_messages=trend_etl.tasks.read_kafka_messages:main",
        "uuid_assignment": "uuid_assignment=trend_etl.tasks.uuid_assignment:main",
        "load_community_groups": "load_community_groups=trend_etl.tasks.load_community_groups:main",
        "load_groups": "load_groups=trend_etl.tasks.load_groups:main",
        "load_subreddits": "load_subreddits=trend_etl.tasks.load_subreddits:main",
        "load_posts": "load_posts=trend_etl.tasks.load_posts:main",
        "load_submissions": "load_submissions=trend_etl.tasks.load_submissions:main",
        "load_comments": "load_comments=trend_etl.tasks.load_comments:main",
        "load_replies": "load_replies=trend_etl.tasks.load_replies:main",
        "load_docs_posts": "load_docs_posts=trend_etl.tasks.load_docs_posts:main",
        "load_docs_comments": "load_docs_comments=trend_etl.tasks.load_docs_comments:main",
        "load_docs_submissions": "load_docs_submissions=trend_etl.tasks.load_docs_submissions:main",
        "load_docs_replies": "load_docs_replies=trend_etl.tasks.load_docs_replies:main",
        "load_daily_ingestion_counts": "load_daily_ingestion_counts=trend_etl.tasks.load_daily_ingestion_counts:main",
        "load_job_run_ingestion_counts": "load_job_run_ingestion_counts=trend_etl.tasks.load_job_run_ingestion_counts:main",
        "report_statements": "report_statements=trend_etl.tasks.report_statements:main",
        "classify_new_subreddits": "classify_new_subreddits=trend_etl.tasks.classify_new_subreddits:main",
    },
    install_requires=[
        "pyspark",
        "delta-spark",
        "boto3",
        "boto3-stubs[essential]",
        "pymongo",
        "numpy",
        "pandas",
        "slack_sdk",
    ],
    extras_require={
        "develop": [
            "setuptools",
            "mypy",
            "build",
            "pandas-stubs",
            "pyarrow",
            # "databricks-connect",
        ],
        "ci": [
            "setuptools",
            "mypy",
            "build",
            "devpi-client",
            "pandas-stubs",
            "pyarrow",
        ],
        "analysis": [
            "spacy[cuda11x,transformers,lookups]>=3.4,<3.5",
        ],
        "classify": [
            "datasets>=2.14,<2.15",
            "transformers>=4.32,<4.33",
            "tensorflow>=2.13,<2.14",
        ],
    },
)
