import unittest
from unittest.mock import Mock

from pyspark.sql import SparkSession
from pyspark.testing import assertDataFrameEqual
from trend_etl.test_utils import getspark
from trend_etl.functions.index import merge_drop_duplicates
import trend_etl.schema.fields as fields


class TestFunctions(unittest.TestCase):
    spark: SparkSession

    @classmethod
    def setUpClass(cls) -> None:
        cls.spark = getspark()

    def test_merge_drop_dupes_noop(self) -> None:
        data = [("apple", 1, 42), ("lemon", 1, 69)]
        df = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        got1 = merge_drop_duplicates(df, "keep-oldest", "fruit", "picked_on")
        got2 = merge_drop_duplicates(df, "keep-newest", "fruit", "picked_on")
        assertDataFrameEqual(got1, df)
        assertDataFrameEqual(got2, df)

    def test_merge_drop_dupes_oldest(self) -> None:
        data = [("apple", 1, 42), ("apple", 2, 1337), ("lemon", 1, 69)]
        df = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        got = merge_drop_duplicates(df, "keep-oldest", "fruit", "picked_on")
        data = [("apple", 1, 42), ("lemon", 1, 69)]
        want = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        assertDataFrameEqual(got, want)

    def test_merge_drop_dupes_newest(self) -> None:
        data = [("apple", 1, 42), ("apple", 2, 1337), ("lemon", 1, 69)]
        df = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        got = merge_drop_duplicates(df, "keep-newest", "fruit", "picked_on")
        data = [("apple", 2, 1337), ("lemon", 1, 69)]
        want = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        assertDataFrameEqual(got, want)

    def test_merge_drop_dupes_dupes(self) -> None:
        data = [("apple", 1, 42), ("apple", 1, 24), ("lemon", 1, 69)]
        df = self.__class__.spark.createDataFrame(
            data, schema="fruit string, picked_on int, number_collected int"
        )
        got = merge_drop_duplicates(df, "keep-oldest", "fruit", "picked_on")
        self.assertEqual(2, got.count(), "dataframe size different")
