from pyspark.sql import DataFrame

from pyspark.sql.functions import col, lit, get_json_object
from pyspark.sql.types import StringType, BinaryType, TimestampType

import trend_etl.schema.fields as fields
from trend_etl.functions.index import (
    discord_snowflake_timestamp,
    get_created_day,
)


#
# arguments:
#   input_df: dataframe received from reading a kafka topic
#   target_topic: source topic from kafka
# return: a dataframe in the schema expected for bronze tables
def from_kafka_get_bronze_guilds_df(
    input_df: DataFrame, target_topic: str
) -> DataFrame:
    snowflake_id = discord_snowflake_timestamp(
        get_json_object(col(fields.kafka_value_field).cast(StringType()), "$.id")
    )

    return input_df.select(
        col(fields.kafka_value_field).alias(fields.bronze_value_field),
        lit(f"kafka/{target_topic}").alias(fields.bronze_provenance_field),
        col(fields.kafka_timestamp_field).alias(fields.bronze_timestamp_field),
        get_created_day(snowflake_id).alias(fields.created_day_field),
    )
